@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkMinMaxCurvatureFlowImageFilter.h,v $
   Language:  C++
-  Date:      $Date: 2006-03-31 14:31:05 $
-  Version:   $Revision: 1.14 $
+  Date:      $Date: 2009-04-23 03:53:36 $
+  Version:   $Revision: 1.16 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -14,8 +14,8 @@
      PURPOSE.  See the above copyright notices for more information.
 
 =========================================================================*/
-#ifndef __itkMinMaxCurvatureFlowImageFilter_h_
-#define __itkMinMaxCurvatureFlowImageFilter_h_
+#ifndef __itkMinMaxCurvatureFlowImageFilter_h
+#define __itkMinMaxCurvatureFlowImageFilter_h
 
 #include "itkCurvatureFlowImageFilter.h"
 #include "itkMinMaxCurvatureFlowFunction.h"
@@ -23,54 +23,54 @@
 namespace itk {
 
 /** \class MinMaxCurvatureFlowImageFilter
-  * \brief Denoise an image using min/max curvature flow.
-  *
-  * MinMaxCurvatureFlowImageFilter implements a curvature driven image denoising 
-  * algorithm. Iso-brightness contours in the grayscale input image are viewed 
-  * as a level set. The level set is then evolved using a curvature-based speed 
-  * function:
-  *
-  * \f[  I_t = F_{\mbox{minmax}} |\nabla I| \f]
-  *
-  * where \f$ F_{\mbox{minmax}} = \max(\kappa,0) \f$ if 
-  * \f$ \mbox{Avg}_{\mbox{stencil}}(x) \f$ is less than or equal to \f$ T_{thresold} \f$ 
-  * and \f$ \min(\kappa,0) \f$, otherwise. 
-  * \f$ \kappa \f$ is the mean curvature of the iso-brightness contour
-  * at point \f$ x \f$.
-  *
-  * In min/max curvature flow, movement is turned on or off depending
-  * on the scale of the noise one wants to remove. Switching depends on
-  * the average image value of a region of radius \f$ R \f$ around each 
-  * point. The choice of \f$ R \f$, the stencil radius, governs the scale of
-  * the noise to be removed.
-  *
-  * The threshold value \f$ T_{threshold} \f$ is the average intensity obtained
-  * in the direction perpendicular to the gradient at point \f$ x \f$ at the
-  * extrema of the local neighborhood.
-  *
-  * This filter make use of the multi-threaded finite difference solver
-  * hierarchy.  Updates are computed using a MinMaxCurvatureFlowFunction object.
-  * A zero flux Neumann boundary condition is used when computing derivatives 
-  * near the data boundary.
-  *
-  * \warning This filter assumes that the input and output types have the
-  * same dimensions. This filter also requires that the output image pixels
-  * are of a real type. This filter works for any dimensional images, 
-  * however for dimensions greater than 3D, an expensive brute-force search 
-  * is used to compute the local threshold.
-  *
-  * Reference:
-  * "Level Set Methods and Fast Marching Methods", J.A. Sethian,
-  * Cambridge Press, Chapter 16, Second edition, 1999.
-  *
-  * \sa MinMaxCurvatureFlowFunction
-  * \sa CurvatureFlowImageFilter
-  * \sa BinaryMinMaxCurvatureFlowImageFilter
-  *
-  * \ingroup ImageEnhancement 
-  * \ingroup Multithreaded
-  * 
-  */
+ * \brief Denoise an image using min/max curvature flow.
+ *
+ * MinMaxCurvatureFlowImageFilter implements a curvature driven image denoising 
+ * algorithm. Iso-brightness contours in the grayscale input image are viewed 
+ * as a level set. The level set is then evolved using a curvature-based speed 
+ * function:
+ *
+ * \f[  I_t = F_{\mbox{minmax}} |\nabla I| \f]
+ *
+ * where \f$ F_{\mbox{minmax}} = \max(\kappa,0) \f$ if 
+ * \f$ \mbox{Avg}_{\mbox{stencil}}(x) \f$ is less than or equal to \f$ T_{thresold} \f$ 
+ * and \f$ \min(\kappa,0) \f$, otherwise. 
+ * \f$ \kappa \f$ is the mean curvature of the iso-brightness contour
+ * at point \f$ x \f$.
+ *
+ * In min/max curvature flow, movement is turned on or off depending
+ * on the scale of the noise one wants to remove. Switching depends on
+ * the average image value of a region of radius \f$ R \f$ around each 
+ * point. The choice of \f$ R \f$, the stencil radius, governs the scale of
+ * the noise to be removed.
+ *
+ * The threshold value \f$ T_{threshold} \f$ is the average intensity obtained
+ * in the direction perpendicular to the gradient at point \f$ x \f$ at the
+ * extrema of the local neighborhood.
+ *
+ * This filter make use of the multi-threaded finite difference solver
+ * hierarchy.  Updates are computed using a MinMaxCurvatureFlowFunction object.
+ * A zero flux Neumann boundary condition is used when computing derivatives 
+ * near the data boundary.
+ *
+ * \warning This filter assumes that the input and output types have the
+ * same dimensions. This filter also requires that the output image pixels
+ * are of a real type. This filter works for any dimensional images, 
+ * however for dimensions greater than 3D, an expensive brute-force search 
+ * is used to compute the local threshold.
+ *
+ * Reference:
+ * "Level Set Methods and Fast Marching Methods", J.A. Sethian,
+ * Cambridge Press, Chapter 16, Second edition, 1999.
+ *
+ * \sa MinMaxCurvatureFlowFunction
+ * \sa CurvatureFlowImageFilter
+ * \sa BinaryMinMaxCurvatureFlowImageFilter
+ *
+ * \ingroup ImageEnhancement 
+ * \ingroup Multithreaded
+ * 
+ */
 template <class TInputImage, class TOutputImage>
 class ITK_EXPORT MinMaxCurvatureFlowImageFilter
   : public CurvatureFlowImageFilter<TInputImage, TOutputImage>
@@ -79,9 +79,9 @@ public:
   /** Standard class typedefs. */
   typedef MinMaxCurvatureFlowImageFilter Self;
   typedef CurvatureFlowImageFilter<TInputImage, TOutputImage>
-  Superclass;
-  typedef SmartPointer<Self> Pointer;
-  typedef SmartPointer<const Self>  ConstPointer;
+                                         Superclass;
+  typedef SmartPointer<Self>             Pointer;
+  typedef SmartPointer<const Self>       ConstPointer;
 
   /** Method for creation through the object factory. */
   itkNewMacro(Self);
@@ -92,7 +92,7 @@ public:
 
   /** Inherit typedefs from Superclass. */
   typedef typename Superclass::FiniteDifferenceFunctionType
-  FiniteDifferenceFunctionType;
+                                               FiniteDifferenceFunctionType;
   typedef typename Superclass::OutputImageType OutputImageType;
 
   /** MinMaxCurvatureFlowFunction type. */
@@ -106,11 +106,11 @@ public:
 
   /** Typedef support for the neighbour radius. */
   typedef typename FiniteDifferenceFunctionType::RadiusType RadiusType;
-  typedef typename RadiusType::SizeValueType RadiusValueType;
+  typedef typename RadiusType::SizeValueType                RadiusValueType;
 
   /** Set/Get the stencil radius. */
   itkSetMacro( StencilRadius, RadiusValueType );
-  itkGetMacro( StencilRadius, RadiusValueType );
+  itkGetConstMacro( StencilRadius, RadiusValueType );
 
 #ifdef ITK_USE_CONCEPT_CHECKING
   /** Begin concept checking */
