@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkShiftScaleImageFilter.h,v $
   Language:  C++
-  Date:      $Date: 2006-03-31 14:31:04 $
-  Version:   $Revision: 1.7 $
+  Date:      $Date: 2009-04-25 12:28:09 $
+  Version:   $Revision: 1.9 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -40,32 +40,32 @@ class ITK_EXPORT ShiftScaleImageFilter:
 {
 public:
   /** Standard class typedefs. */
-  typedef ShiftScaleImageFilter         Self;
+  typedef ShiftScaleImageFilter                         Self;
   typedef ImageToImageFilter<TInputImage,TOutputImage>  Superclass;
-  typedef SmartPointer<Self>  Pointer;
-  typedef SmartPointer<const Self>  ConstPointer;
+  typedef SmartPointer<Self>                            Pointer;
+  typedef SmartPointer<const Self>                      ConstPointer;
 
   /** Method for creation through the object factory. */
   itkNewMacro(Self);  
 
   /** Typedef to describe the output and input image region types. */
-  typedef typename TInputImage::RegionType InputImageRegionType;
+  typedef typename TInputImage::RegionType  InputImageRegionType;
   typedef typename TOutputImage::RegionType OutputImageRegionType;
 
   /** Typedef to describe the pointer to the input/output. */  
-  typedef typename TInputImage::Pointer InputImagePointer;
+  typedef typename TInputImage::Pointer  InputImagePointer;
   typedef typename TOutputImage::Pointer OutputImagePointer;
 
   /** Typedef to describe the type of pixel. */
-  typedef typename TInputImage::PixelType InputImagePixelType;
+  typedef typename TInputImage::PixelType  InputImagePixelType;
   typedef typename TOutputImage::PixelType OutputImagePixelType;
 
   /** Typedef to describe the output and input image index and size types. */
-  typedef typename TInputImage::IndexType InputImageIndexType;
-  typedef typename TInputImage::SizeType InputImageSizeType;
-  typedef typename TInputImage::OffsetType InputImageOffsetType;
-  typedef typename TOutputImage::IndexType OutputImageIndexType;
-  typedef typename TOutputImage::SizeType OutputImageSizeType;
+  typedef typename TInputImage::IndexType   InputImageIndexType;
+  typedef typename TInputImage::SizeType    InputImageSizeType;
+  typedef typename TInputImage::OffsetType  InputImageOffsetType;
+  typedef typename TOutputImage::IndexType  OutputImageIndexType;
+  typedef typename TOutputImage::SizeType   OutputImageSizeType;
   typedef typename TOutputImage::OffsetType OutputImageOffsetType;
 
   /** Type to use form computations. */
@@ -73,22 +73,22 @@ public:
       
   /** Image related typedefs. */
   itkStaticConstMacro(ImageDimension, unsigned int,
-                      TInputImage::ImageDimension ) ;
+                      TInputImage::ImageDimension );
 
   /** Run-time type information (and related methods). */
   itkTypeMacro(ShiftScaleImageFilter, ImageToImageFilter);
 
   /** Set/Get the amount to Shift each Pixel. The shift is followed by a Scale. */
   itkSetMacro(Shift,RealType);
-  itkGetMacro(Shift,RealType);
+  itkGetConstMacro(Shift,RealType);
 
   /** Set/Get the amount to Scale each Pixel. The Scale is applied after the Shift. */
   itkSetMacro(Scale,RealType);
-  itkGetMacro(Scale,RealType);
+  itkGetConstMacro(Scale,RealType);
 
   /** Get the number of pixels that underflowed and overflowed. */
-  itkGetMacro(UnderflowCount,long);
-  itkGetMacro(OverflowCount,long);
+  itkGetConstMacro(UnderflowCount,long);
+  itkGetConstMacro(OverflowCount,long);
 
 #ifdef ITK_USE_CONCEPT_CHECKING
   /** Begin concept checking */
@@ -115,7 +115,7 @@ protected:
   /** Multi-thread version GenerateData. */
   void  ThreadedGenerateData (const OutputImageRegionType& 
                               outputRegionForThread,
-                              int threadId) ;
+                              int threadId);
 private:
   ShiftScaleImageFilter(const Self&); //purposely not implemented
   void operator=(const Self&); //purposely not implemented
@@ -125,6 +125,7 @@ private:
 
   long m_UnderflowCount;
   long m_OverflowCount;
+
   Array<long> m_ThreadUnderflow;
   Array<long> m_ThreadOverflow;
 };
