@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkTriangleMeshToBinaryImageFilter.h,v $
   Language:  C++
-  Date:      $Date: 2009-04-25 12:28:11 $
-  Version:   $Revision: 1.11 $
+  Date:      $Date: 2010-06-09 08:46:19 $
+  Version:   $Revision: 1.12 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -79,12 +79,13 @@ public:
   typedef SmartPointer<Self>               Pointer;
   typedef SmartPointer<const Self>         ConstPointer;
 
-  typedef typename TOutputImage::IndexType      IndexType;
-  typedef typename TOutputImage::SizeType       SizeType;
-  typedef TOutputImage                          OutputImageType;
-  typedef typename OutputImageType::Pointer     OutputImagePointer;
-  typedef typename OutputImageType::ValueType   ValueType;
-  typedef typename OutputImageType::SpacingType SpacingType;
+  typedef typename TOutputImage::IndexType        IndexType;
+  typedef typename TOutputImage::SizeType         SizeType;
+  typedef TOutputImage                            OutputImageType;
+  typedef typename OutputImageType::Pointer       OutputImagePointer;
+  typedef typename OutputImageType::ValueType     ValueType;
+  typedef typename OutputImageType::SpacingType   SpacingType;
+  typedef typename OutputImageType::DirectionType DirectionType;
   
   /** Method for creation through the object factory. */
   itkNewMacro(Self);
@@ -137,6 +138,12 @@ public:
   virtual void SetSpacing( const float spacing[3] );
   itkGetConstReferenceMacro(Spacing, SpacingType);
 
+  /** The Direction is a matix of direction cosines
+   *  that specify the direction between samples.
+   * */
+  itkSetMacro(Direction, DirectionType);
+  itkGetConstMacro(Direction, DirectionType);
+
   /** Set/Get the value for pixels inside the spatial object. 
   * By default, this filter will return an image
   * If this "inside" value is changed to a non-null value,
@@ -208,6 +215,7 @@ protected:
   double           m_Tolerance;
   ValueType        m_InsideValue;
   ValueType        m_OutsideValue;
+  DirectionType    m_Direction;
 
   StencilIndexVector m_StencilIndex;
 
