@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkVectorIndexSelectionCastImageFilter.h,v $
   Language:  C++
-  Date:      $Date: 2007-09-27 11:36:41 $
-  Version:   $Revision: 1.14 $
+  Date:      $Date: 2009-04-01 14:42:12 $
+  Version:   $Revision: 1.17 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -35,30 +35,28 @@ public:
   void SetIndex(unsigned int i) { m_Index = i; }
 
   bool operator!=( const VectorIndexSelectionCast & other ) const
-  {
+    {
     if( m_Index != other.m_Index )
       {
       return true;
       }
     return false;
-  }
+    }
   bool operator==( const VectorIndexSelectionCast & other ) const
-  {
+    {
     return !(*this != other);
-  }
-  inline TOutput operator()( const TInput & A )
-  {
+    }
+  inline TOutput operator()( const TInput & A ) const
+    {
     return static_cast<TOutput>( A[m_Index] );
-  }
+    }
       
 private:
   unsigned int m_Index;   
 }; 
 }
 
-
-
- /** \class VectorIndexSelectionCastImageFilter
+/** \class VectorIndexSelectionCastImageFilter
  *
  * \brief Extracts the selected index of the vector that is the input
  * pixel type
@@ -85,11 +83,13 @@ UnaryFunctorImageFilter<TInputImage,TOutputImage,
 public:
   /** Standard class typedefs. */
   typedef VectorIndexSelectionCastImageFilter Self;
-  typedef UnaryFunctorImageFilter<TInputImage,TOutputImage, 
-                                  Functor::VectorIndexSelectionCast< typename TInputImage::PixelType, 
-                                                                     typename TOutputImage::PixelType> > Superclass;
-  typedef SmartPointer<Self> Pointer;
-  typedef SmartPointer<const Self> ConstPointer;
+  typedef UnaryFunctorImageFilter<
+    TInputImage,TOutputImage, 
+    Functor::VectorIndexSelectionCast< typename TInputImage::PixelType, 
+                                       typename TOutputImage::PixelType> >
+                                              Superclass;
+  typedef SmartPointer<Self>                  Pointer;
+  typedef SmartPointer<const Self>            ConstPointer;
     
   /** Method for creation through the object factory. */
   itkNewMacro(Self);
@@ -101,11 +101,11 @@ public:
   /** Get/Set methods for the index */
   void SetIndex(unsigned int i)
     {
-      if (i != this->GetFunctor().GetIndex())
-        {
-        this->GetFunctor().SetIndex(i);
-        this->Modified();
-        }
+    if (i != this->GetFunctor().GetIndex())
+      {
+      this->GetFunctor().SetIndex(i);
+      this->Modified();
+      }
     }
   unsigned int GetIndex(void) const 
     { 
@@ -166,5 +166,4 @@ private:
  
 } // end namespace itk
 
-
 #endif
