@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkImageSource.h,v $
   Language:  C++
-  Date:      $Date: 2007-08-22 12:57:40 $
-  Version:   $Revision: 1.55 $
+  Date:      $Date: 2009-03-12 01:11:08 $
+  Version:   $Revision: 1.59 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -53,9 +53,9 @@ class ITK_EXPORT ImageSource : public ProcessObject
 {
 public:
   /** Standard class typedefs. */
-  typedef ImageSource         Self;
-  typedef ProcessObject  Superclass;
-  typedef SmartPointer<Self>  Pointer;
+  typedef ImageSource               Self;
+  typedef ProcessObject             Superclass;
+  typedef SmartPointer<Self>        Pointer;
   typedef SmartPointer<const Self>  ConstPointer;
   
   /** Smart Pointer type to a DataObject. */
@@ -65,10 +65,14 @@ public:
   itkTypeMacro(ImageSource,ProcessObject);
 
   /** Some convenient typedefs. */
-  typedef TOutputImage OutputImageType;
-  typedef typename OutputImageType::Pointer OutputImagePointer;
+  typedef TOutputImage                         OutputImageType;
+  typedef typename OutputImageType::Pointer    OutputImagePointer;
   typedef typename OutputImageType::RegionType OutputImageRegionType;
-  typedef typename OutputImageType::PixelType OutputImagePixelType;
+  typedef typename OutputImageType::PixelType  OutputImagePixelType;
+
+   /** ImageDimension constant */
+  itkStaticConstMacro(OutputImageDimension, unsigned int,
+                      TOutputImage::ImageDimension);
 
   /** Get the output data of this process object.  The output of this
    * function is not valid until an appropriate Update() method has
@@ -109,6 +113,13 @@ public:
    * For an image, the data generated is for the requested
    * Region, which can be set using ImageBase::SetRequestedRegion().
    * By default, the largest possible region is requested.
+   *
+   * For Filters which have multiple outputs of different types, the
+   * GetOutput() method assumes the output is of OutputImageType. For
+   * the GetOutput(unsigned int) method, a dynamic_cast is performed
+   * incase the filter has outputs of different types or image
+   * types. Derived classes should have names get methods for these
+   * outputs.
    */
   OutputImageType * GetOutput(void);
   OutputImageType * GetOutput(unsigned int idx);
@@ -225,7 +236,7 @@ protected:
    * outputs of a filter. Some filters may want to override this default
    * behavior. For example, a filter may have multiple outputs with
    * varying resolution. Or a filter may want to process data in place by
-   * grafting its input to its output.*/
+   * grafting its input to its output. */
   virtual void AllocateOutputs();
 
   /** If an imaging filter needs to perform processing after the buffer
@@ -267,9 +278,9 @@ protected:
 
   /** Internal structure used for passing image data into the threading library */
   struct ThreadStruct
-  {
-   Pointer Filter;
-  };
+    {
+    Pointer Filter;
+    };
   
 private:
   ImageSource(const Self&); //purposely not implemented
@@ -294,4 +305,3 @@ private:
 #endif
 
 #endif
-  
