@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkInPlaceImageFilter.h,v $
   Language:  C++
-  Date:      $Date: 2007-01-30 20:56:08 $
-  Version:   $Revision: 1.5 $
+  Date:      $Date: 2009-05-04 14:42:59 $
+  Version:   $Revision: 1.8 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -63,23 +63,23 @@ class ITK_EXPORT InPlaceImageFilter : public ImageToImageFilter<TInputImage, TOu
 {
 public:
   /** Standard class typedefs. */
-  typedef InPlaceImageFilter  Self;
+  typedef InPlaceImageFilter                             Self;
   typedef ImageToImageFilter<TInputImage, TOutputImage>  Superclass;
-  typedef SmartPointer<Self>  Pointer;
-  typedef SmartPointer<const Self>  ConstPointer;
+  typedef SmartPointer<Self>                             Pointer;
+  typedef SmartPointer<const Self>                       ConstPointer;
   
   
   /** Run-time type information (and related methods). */
   itkTypeMacro(InPlaceImageFilter,ImageToImageFilter);
 
   /** Superclass typedefs. */
-  typedef typename Superclass::OutputImageType OutputImageType;
-  typedef typename Superclass::OutputImagePointer OutputImagePointer;
+  typedef typename Superclass::OutputImageType       OutputImageType;
+  typedef typename Superclass::OutputImagePointer    OutputImagePointer;
   typedef typename Superclass::OutputImageRegionType OutputImageRegionType;
-  typedef typename Superclass::OutputImagePixelType OutputImagePixelType;
+  typedef typename Superclass::OutputImagePixelType  OutputImagePixelType;
 
   /** Some convenient typedefs. */
-  typedef TInputImage InputImageType;
+  typedef TInputImage                             InputImageType;
   typedef typename InputImageType::Pointer        InputImagePointer;
   typedef typename InputImageType::ConstPointer   InputImageConstPointer;
   typedef typename InputImageType::RegionType     InputImageRegionType; 
@@ -91,10 +91,13 @@ public:
   itkStaticConstMacro(OutputImageDimension, unsigned int,
                       TOutputImage::ImageDimension);
 
-  /** In place operation can be turned on and off. This only has an
-   * effect when the input and output image type match. */
+  /** In place operation can be turned on and off. Asking for
+   * in-place operation, i.e. calling SetInplace(true) or InplaceOn(),
+   * will be effective only if CanRunInPlace also returns true.
+   * By default CanRunInPlace checks whether the input and output
+   * image type match. */
   itkSetMacro(InPlace, bool);
-  itkGetMacro(InPlace, bool);
+  itkGetConstMacro(InPlace, bool);
   itkBooleanMacro(InPlace);
 
   /** Can the filter run in place? To do so, the filter's first input
@@ -102,13 +105,15 @@ public:
    * method can be used in conjunction with the InPlace ivar to
    * determine whether a particular use of the filter is really
    * running in place. Some filters may be able to optimize their
-   * operation if the InPlace is true and CanRunInPlace is true. */
-   bool CanRunInPlace() const
-     {
-       return (typeid(TInputImage) == typeid(TOutputImage));
-     };
+   * operation if the InPlace is true and CanRunInPlace is true.
+   * CanRunInPlace may also be overridded by InPlaceImageFilter
+   * subclasses to fine tune its behavior. */
+  virtual bool CanRunInPlace() const
+    {
+    return (typeid(TInputImage) == typeid(TOutputImage));
+    }
 
- protected:
+protected:
   InPlaceImageFilter();
   ~InPlaceImageFilter();
 
