@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkMesh.h,v $
   Language:  C++
-  Date:      $Date: 2007-12-21 15:25:34 $
-  Version:   $Revision: 1.96 $
+  Date:      $Date: 2009-09-17 11:14:56 $
+  Version:   $Revision: 1.99 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -171,13 +171,16 @@ public:
                       CoordRepType,PointsContainer>   BoundingBoxType;
 
   /** Create types that are pointers to each of the container types. */
-  typedef typename PointsContainer::Pointer       PointsContainerPointer;
-  typedef typename CellsContainer::Pointer        CellsContainerPointer;
-  typedef typename CellLinksContainer::Pointer    CellLinksContainerPointer;
-  typedef typename PointDataContainer::Pointer    PointDataContainerPointer;
-  typedef typename CellDataContainer::Pointer     CellDataContainerPointer;
-  typedef typename PointLocatorType::Pointer      PointLocatorPointer;
-  typedef typename BoundingBoxType::Pointer       BoundingBoxPointer;
+  typedef typename PointsContainer::Pointer           PointsContainerPointer;
+  typedef typename CellsContainer::Pointer            CellsContainerPointer;
+  typedef typename CellsContainer::ConstPointer       CellsContainerConstPointer;
+  typedef typename CellLinksContainer::Pointer        CellLinksContainerPointer;
+  typedef typename PointDataContainer::Pointer        PointDataContainerPointer;
+  typedef typename CellDataContainer::Pointer         CellDataContainerPointer;
+  typedef typename CellDataContainer::ConstPointer    CellDataContainerConstPointer;
+  typedef typename PointLocatorType::Pointer          PointLocatorPointer;
+  typedef typename BoundingBoxType::Pointer           BoundingBoxPointer;
+  typedef typename CellLinksContainer::ConstPointer   CellLinksContainerConstPointer;
 
   /** Create types that are iterators for each of the container types. */
   typedef typename
@@ -281,7 +284,7 @@ protected:
   /** An object containing parent cell links for each point.  Since a point
    *  can be used by multiple cells, each point identifier accesses another
    *  container which holds the cell identifiers */
-  CellLinksContainerPointer  m_CellLinksContainer;
+  mutable CellLinksContainerPointer  m_CellLinksContainer;
 
   /** A vector of objects containing explicit cell boundary assignments.
    *  The vector is indexed by the topological dimension of the cell
@@ -310,23 +313,23 @@ public:
    * cell identifiers */
   void SetCellLinks(CellLinksContainer*);
 #ifndef CABLE_CONFIGURATION
-  CellLinksContainerPointer GetCellLinks();
-  const CellLinksContainerPointer GetCellLinks() const;
+  CellLinksContainer * GetCellLinks();
+  const CellLinksContainer * GetCellLinks() const;
 
   /** Access m_CellsContainer, which holds cells used by the mesh.
    *  Individual cells are accessed through cell identifiers.  */
   void SetCells(CellsContainer*);
 
-  CellsContainerPointer GetCells();
-  const CellsContainerPointer GetCells() const;
+  CellsContainer * GetCells();
+  const CellsContainer * GetCells() const;
 #endif
   /** Access m_CellDataContainer, which contains data associated with
    *  the mesh's cells.  Optionally, this can be NULL, indicating that
    *  no data are associated with the cells.  The data for a cell can
    *  be accessed through its cell identifier.  */
   void SetCellData(CellDataContainer*);
-  CellDataContainerPointer GetCellData();
-  const CellDataContainerPointer GetCellData() const;
+  CellDataContainer *  GetCellData();
+  const CellDataContainer * GetCellData() const;
 
   /**
    * Set/get the BoundaryAssignmentsContainer for a given dimension.
@@ -427,7 +430,7 @@ public:
 #endif
   /** Dynamically build the links from points back to their using cells.  This
    * information is stored in the cell links container, not in the points. */
-  void BuildCellLinks();
+  void BuildCellLinks() const;
 
 #ifndef CABLE_CONFIGURATION
   /** Get the bounding box of a cell in the mesh. The user
@@ -439,7 +442,7 @@ public:
   /** This method iterates over all the cells in the mesh and has
    *  each cell Accept the MultiVisitor. See MultiVisitor for more
    *  information.  (Note, this follows the Visitor Design Pattern.) */
-  virtual void Accept(CellMultiVisitorType* mv);
+  virtual void Accept(CellMultiVisitorType* mv) const;
 #endif
   /** Set/Get the identification of the method used to allocate cells
       \warning Failure to call this method correctly will lead to memory leaks
