@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkRigid2DTransform.h,v $
   Language:  C++
-  Date:      $Date: 2007-04-05 17:02:10 $
-  Version:   $Revision: 1.21 $
+  Date:      $Date: 2009-11-29 01:38:00 $
+  Version:   $Revision: 1.26 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -24,7 +24,7 @@
 namespace itk
 {
 
-/** \class Rigig2DTransform 
+/** \class Rigid2DTransform 
  * \brief Rigid2DTransform of a vector space (e.g. space coordinates)
  *
  * This transform applies a rigid transformation in 2D space.
@@ -80,20 +80,24 @@ public:
   typedef typename Superclass::ScalarType  ScalarType;
 
   /** Parameters type. */
-  typedef typename Superclass::ParametersType  ParametersType;
+  typedef typename Superclass::ParametersType       ParametersType;
+  typedef typename Superclass::ParametersValueType  ParametersValueType;
 
   /** Jacobian type. */
   typedef typename Superclass::JacobianType  JacobianType;
 
   /// Standard matrix type for this class
-  typedef typename Superclass::MatrixType MatrixType;
+  typedef typename Superclass::MatrixType         MatrixType;
+  typedef typename Superclass::MatrixValueType    MatrixValueType;
 
   /// Standard vector type for this class
-  typedef typename Superclass::OffsetType OffsetType;
+  typedef typename Superclass::OffsetType         OffsetType;
+  typedef typename Superclass::OffsetValueType    OffsetValueType;
 
   /// Standard vector type for this class
-  typedef typename Superclass::InputVectorType  InputVectorType;
-  typedef typename Superclass::OutputVectorType OutputVectorType;
+  typedef typename Superclass::InputVectorType        InputVectorType;
+  typedef typename Superclass::OutputVectorType       OutputVectorType;
+  typedef typename Superclass::OutputVectorValueType  OutputVectorValueType;
 
   /// Standard covariant vector type for this class
   typedef typename Superclass::InputCovariantVectorType InputCovariantVectorType;
@@ -107,6 +111,11 @@ public:
   typedef typename Superclass::InputPointType  InputPointType;
   typedef typename Superclass::OutputPointType OutputPointType;
 
+  /** Base inverse transform type. This type should not be changed to the
+   * concrete inverse transform type or inheritance would be lost. */
+  typedef typename Superclass::InverseTransformBaseType InverseTransformBaseType;
+  typedef typename InverseTransformBaseType::Pointer    InverseTransformBasePointer;
+
   /**
    * Set the rotation Matrix of a Rigid2D Transform
    *
@@ -203,6 +212,12 @@ public:
    */
   void CloneInverseTo( Pointer & newinverse ) const;
 
+  /** Get an inverse of this transform. */
+  bool GetInverse(Self* inverse) const;
+
+  /** Return an inverse of this transform. */
+  virtual InverseTransformBasePointer GetInverseTransform() const;
+
   /**
    * This method creates and returns a new Rigid2DTransform object
    * which has the same parameters.
