@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkRigid3DTransform.h,v $
   Language:  C++
-  Date:      $Date: 2009-06-17 12:17:38 $
-  Version:   $Revision: 1.41 $
+  Date:      $Date: 2009-11-28 15:58:04 $
+  Version:   $Revision: 1.43 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -70,10 +70,12 @@ public:
   itkStaticConstMacro(ParametersDimension, unsigned int, 12);
 
   typedef typename Superclass::ParametersType             ParametersType;
+  typedef typename Superclass::ParametersValueType        ParametersValueType;
   typedef typename Superclass::JacobianType               JacobianType;
   typedef typename Superclass::ScalarType                 ScalarType;
   typedef typename Superclass::InputVectorType            InputVectorType;
   typedef typename Superclass::OutputVectorType           OutputVectorType;
+  typedef typename Superclass::OutputVectorValueType      OutputVectorValueType;
   typedef typename Superclass::InputCovariantVectorType  
                                                           InputCovariantVectorType;
   typedef typename Superclass::OutputCovariantVectorType  
@@ -84,12 +86,13 @@ public:
   typedef typename Superclass::OutputPointType            OutputPointType;
   typedef typename Superclass::MatrixType                 MatrixType;
   typedef typename Superclass::InverseMatrixType          InverseMatrixType;
+  typedef typename Superclass::MatrixValueType            MatrixValueType;
   typedef typename Superclass::CenterType                 CenterType;
   typedef typename Superclass::TranslationType            TranslationType;
   typedef typename Superclass::OffsetType                 OffsetType;
 
   /** Base inverse transform type. This type should not be changed to the
-   * concrete inverse transform type or inheritance would be lost.*/
+   * concrete inverse transform type or inheritance would be lost. */
   typedef typename Superclass::InverseTransformBaseType InverseTransformBaseType;
   typedef typename InverseTransformBaseType::Pointer    InverseTransformBasePointer;
 
