@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkEllipseSpatialObject.h,v $
   Language:  C++
-  Date:      $Date: 2007-01-28 19:24:21 $
-  Version:   $Revision: 1.26 $
+  Date:      $Date: 2009-04-07 14:33:56 $
+  Version:   $Revision: 1.29 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -27,11 +27,11 @@ namespace itk
 
 /** \class EllipseSpatialObject
  * 
- * \brief 
+ * \brief TODO
  */
 
 template < unsigned int TDimension = 3 >
-class EllipseSpatialObject 
+class ITK_EXPORT EllipseSpatialObject 
   : public SpatialObject< TDimension >
 {
 
@@ -73,7 +73,7 @@ public:
                         char * name=NULL) const;
      
   /** Return true if the object provides a method to evaluate the value 
-   * at the specified point, false otherwise.*/
+   * at the specified point, false otherwise. */
   virtual bool IsEvaluableAt( const PointType & point, 
                               unsigned int depth=0,
                               char * name=NULL) const;
