@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: FFTImageFilter.cxx,v $
   Language:  C++
-  Date:      $Date: 2009-03-16 21:52:48 $
-  Version:   $Revision: 1.15 $
+  Date:      $Date: 2009-11-06 09:20:10 $
+  Version:   $Revision: 1.16 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -72,9 +72,9 @@
 
 int main( int argc, char * argv [] )
 {
-  if( argc < 4 )
+  if( argc < 5 )
     {
-    std::cerr << "Usage: " << argv[0] << " inputScalarImage  outputRealPartOfComplexImage outputRealImaginaryPartOfComplexImage" << std::endl;
+    std::cerr << "Usage: " << argv[0] << " inputScalarImage  outputRealPartOfComplexImage outputRealImaginaryPartOfComplexImage outputComplex" << std::endl;
     }
 
 
@@ -162,7 +162,7 @@ int main( int argc, char * argv [] )
   typedef itk::ImageFileWriter< ComplexImageType > ComplexWriterType;
 
   ComplexWriterType::Pointer complexWriter = ComplexWriterType::New();
-  complexWriter->SetFileName("complexImage.mhd");
+  complexWriter->SetFileName( argv[4] );
 
   complexWriter->SetInput( fftFilter->GetOutput() );
 // Software Guide : EndCodeSnippet
@@ -325,7 +325,7 @@ int main( int argc, char * argv [] )
   
   ComplexReaderType::Pointer complexReader = ComplexReaderType::New();
 
-  complexReader->SetFileName("complexImage.mhd");
+  complexReader->SetFileName( argv[4] );
   complexReader->Update();
   // Software Guide : EndCodeSnippet
 
