@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkAlgorithmsTests4.cxx,v $
   Language:  C++
-  Date:      $Date: 2009-10-17 21:35:23 $
-  Version:   $Revision: 1.16 $
+  Date:      $Date: 2010-07-06 14:50:30 $
+  Version:   $Revision: 1.20 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -28,6 +28,9 @@ void RegisterTests()
   vnl_sample_reseed(8775070);
   REGISTER_TEST(itkCollidingFrontsImageFilterTest );
   REGISTER_TEST(itkBayesianClassifierImageFilterTest );
+#if defined(ITK_USE_CENTERED_PIXEL_COORDINATES_CONSISTENTLY)
+  REGISTER_TEST(itkBinaryMedialNodeMetricTest); //Test disabled when centerd coordinates not used
+#endif
   REGISTER_TEST(itkCurvesLevelSetImageFilterZeroSigmaTest );
   REGISTER_TEST(itkFastMarchingUpwindGradientTest );
   REGISTER_TEST(itkGeodesicActiveContourLevelSetImageFilterZeroSigmaTest );
@@ -57,5 +60,6 @@ void RegisterTests()
   REGISTER_TEST(itkThresholdMaximumConnectedComponentsImageFilterTest );
   REGISTER_TEST(itkScalarImageKmeansImageFilter3DTest );
   REGISTER_TEST(itkLevelSetMotionRegistrationFilterTest );
+  REGISTER_TEST(itkVoronoiSegmentationRGBImageFilterTest );
 }
 
