@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkImagePCAShapeModelEstimatorTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2008-02-03 04:05:34 $
-  Version:   $Revision: 1.11 $
+  Date:      $Date: 2010-04-22 10:38:01 $
+  Version:   $Revision: 1.13 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -28,13 +28,6 @@
 
 #include "itkImagePCAShapeModelEstimator.h"
 
-//Data definitions 
-#define   IMGWIDTH            2
-#define   IMGHEIGHT           2
-#define   NDIMENSION          2
-#define   NUMTRAINIMAGES      3
-#define   NUMLARGESTPC        2
-
 // class to support progress feeback
 
 
@@ -51,6 +44,12 @@ public:
 
 int itkImagePCAShapeModelEstimatorTest(int, char* [] )
 {
+  //Data definitions 
+  int IMGWIDTH          = 2;
+  int IMGHEIGHT         = 2;
+  const int NDIMENSION  = 2;
+  unsigned int NUMTRAINIMAGES = 3;
+  unsigned int NUMLARGESTPC = 2;
 
   itk::OutputWindow::SetInstance(itk::TextOutput::New().GetPointer());
 
@@ -87,9 +86,9 @@ int itkImagePCAShapeModelEstimatorTest(int, char* [] )
   region.SetSize( inputImageSize );
   region.SetIndex( index );
 
-  //--------------------------------------------------------------------------
+  //------------------------------------------------------------------------
   // Set up Image 1 first
-  //--------------------------------------------------------------------------
+  //------------------------------------------------------------------------
 
   image1->SetLargestPossibleRegion( region );
   image1->SetBufferedRegion( region );
@@ -98,9 +97,9 @@ int itkImagePCAShapeModelEstimatorTest(int, char* [] )
   // setup the iterators
   InputImageIterator image1It( image1, image1->GetBufferedRegion() );
 
-  //--------------------------------------------------------------------------
+  //------------------------------------------------------------------------
   // Set up Image 2 first
-  //--------------------------------------------------------------------------
+  //------------------------------------------------------------------------
 
   image2->SetLargestPossibleRegion( region );
   image2->SetBufferedRegion( region );
@@ -109,9 +108,9 @@ int itkImagePCAShapeModelEstimatorTest(int, char* [] )
   // setup the iterators
   InputImageIterator image2It( image2, image2->GetBufferedRegion() );
 
-  //--------------------------------------------------------------------------
+  //------------------------------------------------------------------------
   // Set up Image 3 first
-  //--------------------------------------------------------------------------
+  //------------------------------------------------------------------------
 
   image3->SetLargestPossibleRegion( region );
   image3->SetBufferedRegion( region );
@@ -120,9 +119,9 @@ int itkImagePCAShapeModelEstimatorTest(int, char* [] )
   // setup the iterators
   InputImageIterator image3It( image3, image3->GetBufferedRegion() );
 
-  //--------------------------------------------------------------------------
+  //------------------------------------------------------------------------
   //Manually create and store each vector
-  //--------------------------------------------------------------------------
+  //------------------------------------------------------------------------
   //Image no. 1
   for( int i = 0; i< 4; i++ )
     {
@@ -190,7 +189,7 @@ int itkImagePCAShapeModelEstimatorTest(int, char* [] )
     applyPCAShapeEstimator->GetNumberOfPrincipalComponentsRequired() << 
     " largest eigen values are:" << std::endl;
 
-  for(unsigned int i= 0; i< vnl_math_min( numEigVal, (unsigned int)NUMLARGESTPC ); i++ )
+  for(unsigned int i= 0; i< vnl_math_min( numEigVal, NUMLARGESTPC ); i++ )
     {
     std::cout << eigenValues[ i ] << std::endl; 
     }  
