@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkAdaptImageFilterTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2006-01-15 04:28:36 $
-  Version:   $Revision: 1.10 $
+  Date:      $Date: 2010-06-28 14:20:03 $
+  Version:   $Revision: 1.12 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -193,12 +193,12 @@ int itkAdaptImageFilterTest(int, char* [] ) {
   std::cout << std::endl;
   if (passed)
     {
-    std::cout << "AdaptImageFilterTest passed" << std::endl;
+    std::cout << "AdaptImageFilterTest passed." << std::endl;
     return EXIT_SUCCESS;
     }
   else
     {
-    std::cout << "AdaptImageFilterTest passed" << std::endl;
+    std::cerr << "AdaptImageFilterTest failed." << std::endl;
     return EXIT_FAILURE;
     }
 }
