@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkComplexToImaginaryFilterAndAdaptorTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2007-08-10 14:34:01 $
-  Version:   $Revision: 1.2 $
+  Date:      $Date: 2009-04-05 23:09:35 $
+  Version:   $Revision: 1.3 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -124,23 +124,23 @@ int itkComplexToImaginaryFilterAndAdaptorTest(int, char* [] )
   ot.GoToBegin();
   it.GoToBegin();
   while( !ot.IsAtEnd() ) 
-  {
+    {
     std::cout <<  ot.Get() << " = ";
     std::cout <<  it.Get().imag()  << std::endl; 
     const InputImageType::PixelType  input  = it.Get();
     const OutputImageType::PixelType output = ot.Get();
     const OutputImageType::PixelType imag  = input.imag();
-    if( fabs( imag - output ) > epsilon )
-    {
+    if( vcl_fabs( imag - output ) > epsilon )
+      {
       std::cerr << "Error in itkComplexToImaginaryImageFilterTest " << std::endl;
       std::cerr << " imag( " << input << ") = " << imag << std::endl;
       std::cerr << " differs from " << output;
       std::cerr << " by more than " << epsilon << std::endl;
       return EXIT_FAILURE;
-    }
+      }
     ++ot;
     ++it;
-  }
+    }
 
 
 
@@ -179,27 +179,21 @@ int itkComplexToImaginaryFilterAndAdaptorTest(int, char* [] )
   
   dt.GoToBegin();
   while( !dt.IsAtEnd() ) 
-  {
+    {
     std::cout <<  dt.Get() << std::endl;
     const OutputImageType::PixelType diff = dt.Get();
-    if( fabs( diff ) > epsilon )
-    {
+    if( vcl_fabs( diff ) > epsilon )
+      {
       std::cerr << "Error in itkComplexToImaginaryImageFilterTest " << std::endl;
       std::cerr << "Comparing results with Adaptors" << std::endl;
       std::cerr << " difference = " << diff << std::endl;
       std::cerr << " differs from 0 ";
       std::cerr << " by more than " << epsilon << std::endl;
       return EXIT_FAILURE;
-    }
+      }
     ++dt;
-  }
-
+    }
 
 
   return EXIT_SUCCESS;
-
 }
-
-
-
-
