@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkHausdorffDistanceImageFilterTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2003-09-10 14:30:06 $
-  Version:   $Revision: 1.7 $
+  Date:      $Date: 2008-07-24 13:57:44 $
+  Version:   $Revision: 1.8 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -101,12 +101,18 @@ int itkHausdorffDistanceImageFilterTest(int, char* [] )
 
   std::cout << " True distance: " << trueDistance << std::endl;
   std::cout << " Computed computed: " << distance << std::endl;
+  std::cout << " Average distance: " << filter->GetAverageHausdorffDistance() << std::endl;
 
   if ( vnl_math_abs( trueDistance - distance ) > 0.1 )
     {
     std::cout << "Test failed. " << std::endl;
     return EXIT_FAILURE;
     }
+  if ( vnl_math_abs( 6.5 - filter->GetAverageHausdorffDistance() ) > 0.1 )
+    {
+    std::cout << "Test failed, average distance too great. " << std::endl;
+    return EXIT_FAILURE;
+    }
   }
 
   // compute the directed Hausdorff distance h(image2,image1)
@@ -126,12 +132,18 @@ int itkHausdorffDistanceImageFilterTest(int, char* [] )
 
   std::cout << " True distance: " << trueDistance << std::endl;
   std::cout << " Computed computed: " << distance << std::endl;
+  std::cout << " Average distance: " << filter->GetAverageHausdorffDistance() << std::endl;
 
   if ( vnl_math_abs( trueDistance - distance ) > 0.1 )
     {
     std::cout << "Test failed. " << std::endl;
     return EXIT_FAILURE;
     }
+  if ( vnl_math_abs( 2.5 - filter->GetAverageHausdorffDistance() ) > 0.1 )
+    {
+    std::cout << "Test failed, average distance too great. " << std::endl;
+    return EXIT_FAILURE;
+    }
   }
 
 
@@ -152,12 +164,18 @@ int itkHausdorffDistanceImageFilterTest(int, char* [] )
 
   std::cout << " True distance: " << trueDistance << std::endl;
   std::cout << " Computed computed: " << distance << std::endl;
+  std::cout << " Average distance: " << filter->GetAverageHausdorffDistance() << std::endl;
 
   if ( vnl_math_abs( trueDistance - distance ) > 0.1 )
     {
     std::cout << "Test failed. " << std::endl;
     return EXIT_FAILURE;
     }
+  if ( vnl_math_abs( 4.5 - filter->GetAverageHausdorffDistance() ) > 0.1 )
+    {
+    std::cout << "Test failed, average distance too great. " << std::endl;
+    return EXIT_FAILURE;
+    }
   }
 
   // compute the Hausdorff distance H(image2,image1)
@@ -177,12 +195,18 @@ int itkHausdorffDistanceImageFilterTest(int, char* [] )
 
   std::cout << " True distance: " << trueDistance << std::endl;
   std::cout << " Computed computed: " << distance << std::endl;
+  std::cout << " Average distance: " << filter->GetAverageHausdorffDistance() << std::endl;
 
   if ( vnl_math_abs( trueDistance - distance ) > 0.1 )
     {
     std::cout << "Test failed. " << std::endl;
     return EXIT_FAILURE;
     }
+  if ( vnl_math_abs( 4.5 - filter->GetAverageHausdorffDistance() ) > 0.1 )
+    {
+    std::cout << "Test failed, average distance too great. " << std::endl;
+    return EXIT_FAILURE;
+    }
   }
 
 
