@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkSquareImageFilterTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2006-01-15 04:28:36 $
-  Version:   $Revision: 1.4 $
+  Date:      $Date: 2009-04-05 23:09:35 $
+  Version:   $Revision: 1.5 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -124,32 +124,25 @@ int itkSquareImageFilterTest(int, char* [] )
   ot.GoToBegin();
   it.GoToBegin();
   while( !ot.IsAtEnd() ) 
-  {
+    {
     const InputImageType::PixelType  input  = it.Get();
     const OutputImageType::PixelType output = ot.Get();
     const double x1 = input;
     const double x2 = x1 * x1;
     const OutputImageType::PixelType square  = 
             static_cast<OutputImageType::PixelType>( x2 );
-    if( fabs( square - output ) > epsilon )
-    {
+    if( vcl_fabs( square - output ) > epsilon )
+      {
       std::cerr << "Error in itkSquareImageFilterTest " << std::endl;
       std::cerr << " square( " << input << ") = " << square << std::endl;
       std::cerr << " differs from " << output;
       std::cerr << " by more than " << epsilon << std::endl;
       return EXIT_FAILURE;
-    }
+      }
     ++ot;
     ++it;
-  }
-
-
+    }
 
   
   return EXIT_SUCCESS;
-
 }
-
-
-
-
