@@ -3,8 +3,8 @@
 Program:   Insight Segmentation & Registration Toolkit
 Module:    $RCSfile: itkTriangleMeshToSimplexMeshFilter2Test.cxx,v $
 Language:  C++
-Date:      $Date: 2007-05-17 21:03:28 $
-Version:   $Revision: 1.8 $
+Date:      $Date: 2010-06-07 19:23:00 $
+Version:   $Revision: 1.9 $
 
 Copyright (c) Insight Software Consortium. All rights reserved.
 See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -70,10 +70,10 @@ int itkTriangleMeshToSimplexMeshFilter2Test(int , char *[] )
   NeighborsListType* neighbors = 0;
   
   for (int i=0; i < 7; i++)
-  {  
-    itk::TimeProbe * timeProbe = new itk::TimeProbe(); 
+    {  
+    itk::TimeProbe timeProbe;
     
-    timeProbe->Start();
+    timeProbe.Start();
     unsigned int lastIndex = simplexMesh->GetPoints()->Size();
     for (unsigned int pointIndex = 0; pointIndex < lastIndex; pointIndex++)
       {
@@ -83,12 +83,12 @@ int itkTriangleMeshToSimplexMeshFilter2Test(int , char *[] )
         delete neighbors;
         }
       }
-    timeProbe->Stop();
+    timeProbe.Stop();
     std::cout << "Rigidity: " << i << ", neighbor list size: " << neighbors->size() << std::endl;
  
-    std::cout << ", Elapsed time (for getting neighbors): " << timeProbe->GetMeanTime() << std::endl;
+    std::cout << ", Elapsed time (for getting neighbors): " << timeProbe.GetMeanTime() << std::endl;
     delete neighbors;
-  }
+    }
 
     
   
