@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkVotingBinaryIterativeHoleFillingImageFilterTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2007-01-29 14:42:11 $
-  Version:   $Revision: 1.3 $
+  Date:      $Date: 2009-07-12 10:53:02 $
+  Version:   $Revision: 1.4 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -38,13 +38,14 @@ int itkVotingBinaryIterativeHoleFillingImageFilterTest(int, char* [] )
   random->SetMin(   0 );
   random->SetMax( 100 );
 
-  unsigned long randomSize[2];
+  ImageType::SizeValueType randomSize[2];
   randomSize[0] = randomSize[1] = 8;
   random->SetSize(randomSize);
   
-  float spacing[2] = {0.7, 2.1};
+  ImageType::SpacingValueType spacing[2] = {0.7, 2.1};
   random->SetSpacing( spacing );
-  float origin[2] = {15, 400};
+
+  ImageType::PointValueType origin[2] = {15, 400};
   random->SetOrigin( origin );
     
   ImageType::PixelType foreground =  97; // prime numbers are good testers
