@@ -55,11 +55,13 @@ REGISTER_TEST(itkExceptionObjectTest );
 REGISTER_TEST(itkFileOutputWindowTest );
 REGISTER_TEST(itkFiniteCylinderSpatialFunctionTest );
 REGISTER_TEST(itkFixedArrayTest );
+REGISTER_TEST(itkFixedArrayTest2 );
 REGISTER_TEST(itkFixedCenterOfRotationAffineTransformTest );
 REGISTER_TEST(itkFloodFilledSpatialFunctionTest );
 REGISTER_TEST(itkFourierSeriesPathTest );
 REGISTER_TEST(itkGaussianBlurImageFunctionTest);
 REGISTER_TEST(itkGaussianDerivativeImageFunctionTest);
+REGISTER_TEST(itkGaussianSpatialFunctionTest);
 REGISTER_TEST(itkHashTableTest );
 REGISTER_TEST(itkIdentityTransformTest );
 REGISTER_TEST(itkImageAdaptorTest );
@@ -69,6 +71,7 @@ REGISTER_TEST(itkImageDuplicatorTest );
 REGISTER_TEST(itkImageIteratorTest );
 REGISTER_TEST(itkImageIteratorsForwardBackwardTest );
 REGISTER_TEST(itkImageIteratorWithIndexTest );
+REGISTER_TEST(itkImageRegionIteratorTest );
 REGISTER_TEST(itkImageLinearIteratorTest );
 REGISTER_TEST(itkImageRandomIteratorTest );
 REGISTER_TEST(itkImageRandomIteratorTest2 );
