@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkDiffusionTensor3DTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2008-01-18 18:24:13 $
-  Version:   $Revision: 1.7 $
+  Date:      $Date: 2010-03-16 19:56:02 $
+  Version:   $Revision: 1.10 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -49,9 +49,27 @@ int itkDiffusionTensor3DTest(int, char* [] )
     }
   std::cout << "pixel.GetNumberOfComponents = " << pixel.GetNumberOfComponents() << std::endl;
   std::cout << "pixel.GetNthComponent()" << std::endl;
+  bool passed = true;
   for (unsigned int i = 0; i < pixel.GetNumberOfComponents(); i++)
     {
-    std::cout << "\tpixel[" << i << "] = " << pixel.GetNthComponent(i) << std::endl;
+    if (pixel.GetNthComponent(i) != val[i])
+      {
+      std::cout << "Float3DTensorType pixel(val) failed." << std::endl
+                << "\tExpected val["
+                << i
+                << "] = "
+                << val[i]
+                << " but got pixel.GetNthComponent("
+                << i
+                << ") = "
+                << pixel.GetNthComponent(i)
+                << std::endl;
+      passed = false;
+      }
+    else
+      {
+      std::cout << "\tpixel[" << i << "] = " << pixel.GetNthComponent(i) << std::endl;
+      }
     }
 
   pixel(0,0) = 11.0;
@@ -233,7 +251,7 @@ int itkDiffusionTensor3DTest(int, char* [] )
 
       for(unsigned int i=0; i<3; i++)
         {
-        if( fabs( expectedValues[i] - eigenValues[i] ) > tolerance )
+        if( vcl_fabs( expectedValues[i] - eigenValues[i] ) > tolerance )
           {
           std::cerr << "Eigenvalue computation failed" << std::endl;
           std::cerr << "expectedValues = " << expectedValues << std::endl;
@@ -273,7 +291,7 @@ int itkDiffusionTensor3DTest(int, char* [] )
 
       for(unsigned int i=0; i<3; i++)
         {
-        if( fabs( expectedValues[i] - eigenValues[i] ) > tolerance )
+        if( vcl_fabs( expectedValues[i] - eigenValues[i] ) > tolerance )
           {
           std::cerr << "Eigenvalue computation failed" << std::endl;
           std::cerr << "expectedValues = " << expectedValues << std::endl;
@@ -313,7 +331,7 @@ int itkDiffusionTensor3DTest(int, char* [] )
 
       for(unsigned int i=0; i<3; i++)
         {
-        if( fabs( expectedValues[i] - eigenValues[i] ) > tolerance )
+        if( vcl_fabs( expectedValues[i] - eigenValues[i] ) > tolerance )
           {
           std::cerr << "Eigenvalue computation failed" << std::endl;
           std::cerr << "expectedValues = " << expectedValues << std::endl;
@@ -355,7 +373,7 @@ int itkDiffusionTensor3DTest(int, char* [] )
     const double tolerance = 1e-4;
 
     AccumulateValueType computedTrace = tensor3.GetTrace();
-    if( fabs( computedTrace - expectedTrace ) > tolerance )
+    if( vcl_fabs( computedTrace - expectedTrace ) > tolerance )
       {
       std::cerr << "Error computing the Trace" << std::endl;
       std::cerr << "Expected trace = " << expectedTrace << std::endl;
@@ -367,7 +385,7 @@ int itkDiffusionTensor3DTest(int, char* [] )
     const RealValueType expectedInternalScalarProduct = 1829;
 
     RealValueType computedInternalScalarProduct = tensor3.GetInnerScalarProduct();
-    if( fabs( computedInternalScalarProduct - expectedInternalScalarProduct ) > tolerance )
+    if( vcl_fabs( computedInternalScalarProduct - expectedInternalScalarProduct ) > tolerance )
       {
       std::cerr << "Error computing Internal Scalar Product" << std::endl;
       std::cerr << "Expected = " << expectedInternalScalarProduct << std::endl;
@@ -380,7 +398,7 @@ int itkDiffusionTensor3DTest(int, char* [] )
     const RealValueType expectedFractionalAnisotropy = 0.349177;
 
     RealValueType computedFractionalAnisotropy = tensor3.GetFractionalAnisotropy();
-    if( fabs( computedFractionalAnisotropy - expectedFractionalAnisotropy ) > tolerance )
+    if( vcl_fabs( computedFractionalAnisotropy - expectedFractionalAnisotropy ) > tolerance )
       {
       std::cerr << "Error computing Fractional Anisotropy" << std::endl;
       std::cerr << "Expected = " << expectedFractionalAnisotropy << std::endl;
@@ -392,7 +410,7 @@ int itkDiffusionTensor3DTest(int, char* [] )
     const RealValueType expectedRelativeAnisotropy = 1.9044;
 
     RealValueType computedRelativeAnisotropy = tensor3.GetRelativeAnisotropy();
-    if( fabs( computedRelativeAnisotropy - expectedRelativeAnisotropy ) > tolerance )
+    if( vcl_fabs( computedRelativeAnisotropy - expectedRelativeAnisotropy ) > tolerance )
       {
       std::cerr << "Error computing Relative Anisotropy" << std::endl;
       std::cerr << "Expected = " << expectedRelativeAnisotropy << std::endl;
@@ -403,6 +421,69 @@ int itkDiffusionTensor3DTest(int, char* [] )
 
   } // end of Test GetTrace() method
 
-  return EXIT_SUCCESS;
+  //Test Numeric Traits
+  {
+    typedef itk::DiffusionTensor3D<int>             TensorType;
+    
+    typedef itk::NumericTraits<TensorType>::ValueType      ValueType;
+    typedef itk::NumericTraits<TensorType>::AbsType        AbsType;           
+    typedef itk::NumericTraits<TensorType>::AccumulateType AccumulateType;     
+    typedef itk::NumericTraits<TensorType>::FloatType      FloatType;          
+    typedef itk::NumericTraits<TensorType>::PrintType      PrintType;          
+    typedef itk::NumericTraits<TensorType>::RealType       RealType;           
+                                                                        
+    typedef itk::NumericTraits<TensorType>::ScalarRealType ScalarRealType;     
+    
+    TensorType maxTensor = itk::NumericTraits<TensorType>::max();                               
+    TensorType minTensor = itk::NumericTraits<TensorType>::min();                               
+    TensorType nonpositiveMinTensor
+                          = itk::NumericTraits<TensorType>::NonpositiveMin();                               
+    TensorType zeroValue
+                          = itk::NumericTraits<TensorType>::ZeroValue();                               
+    TensorType oneValue
+                          = itk::NumericTraits<TensorType>::OneValue();                               
+
+    TensorType zero = itk::NumericTraits<TensorType>::Zero;
+    TensorType one = itk::NumericTraits<TensorType>::One;
+  }
+
+  //Test casting constructors
+  {  
+    typedef itk::DiffusionTensor3D<int>     Int3DTensorType;
+    typedef itk::DiffusionTensor3D<float>   Float3DTensorType;
+    
+    Int3DTensorType intTensor;
+    intTensor[0] =   1;
+    intTensor[1] =  -2; 
+    intTensor[2] =   3;
+    intTensor[3] =   4;
+    intTensor[4] =   5; 
+    intTensor[5] =   6;
+    
+    //Test constructors
+    Float3DTensorType floatTensor(intTensor);
+    
+    //test Assignment
+    Float3DTensorType floatTensor2 = intTensor;
+    
+    //Test casting
+    Float3DTensorType floatTensor3 = static_cast<Float3DTensorType>(intTensor);
+
+    //Check that all floatTensors have are the same
+    float precision = 1e-6;
+    for (unsigned int i=0;i<Float3DTensorType::InternalDimension;++i)
+    {
+      float intVal = static_cast<float>(intTensor[i]);
+      if ( (floatTensor[i] - intVal) > precision ||
+          (floatTensor2[i] - intVal) > precision ||
+          (floatTensor3[i] - intVal) > precision )
+      {
+        std::cerr << "Error failed casting/templated Constructor Test" << std::endl;
+        return EXIT_FAILURE;
+      }
+    }
+  }
+
+  return (passed ? EXIT_SUCCESS : EXIT_FAILURE);
 }
 
