@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkImageComputeOffsetAndIndexTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2007-04-10 15:45:22 $
-  Version:   $Revision: 1.8 $
+  Date:      $Date: 2010-06-02 13:57:17 $
+  Version:   $Revision: 1.9 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -42,6 +42,7 @@ template <class TImage>
 void ComputeFastIndex(TImage *image, unsigned int count, unsigned int repeat)
 {
   typename TImage::IndexType index;
+  index.Fill( 0 );
   const typename TImage::IndexType &bufferedRegionIndex = image->GetBufferedRegion().GetIndex();
   const typename TImage::OffsetValueType *offsetTable = image->GetOffsetTable();
   
@@ -50,9 +51,9 @@ void ComputeFastIndex(TImage *image, unsigned int count, unsigned int repeat)
     for (unsigned int i = 0; i < count; i++)
       {
       itk::ImageHelper<TImage::ImageDimension,TImage::ImageDimension>::ComputeIndex(bufferedRegionIndex,
-                                                                                    i,
-                                                                                    offsetTable,
-                                                                                    index);
+        i,
+        offsetTable,
+        index);
       }
     }
   std::cout << "Last index: " << index << std::endl;
