@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkIOTests.cxx,v $
   Language:  C++
-  Date:      $Date: 2009-11-02 19:27:54 $
-  Version:   $Revision: 1.84 $
+  Date:      $Date: 2010-06-14 18:55:24 $
+  Version:   $Revision: 1.86 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -94,10 +94,12 @@ void RegisterTests()
   REGISTER_TEST(itkRawImageIOTest4);
   REGISTER_TEST(itkRawImageIOTest5);
   REGISTER_TEST(itkVectorImageReadWriteTest);
+  REGISTER_TEST(itkReadWriteImageWithDictionaryTest);
   REGISTER_TEST(itkReadWriteSpatialObjectTest);
   REGISTER_TEST(itkRegularExpressionSeriesFileNamesTest);
   REGISTER_TEST(itkArchetypeSeriesFileNamesTest);
   REGISTER_TEST(itkSymmetricSecondRankTensorImageReadTest);
+  REGISTER_TEST(itkSymmetricSecondRankTensorImageWriteReadTest);
   REGISTER_TEST(itkStimulateImageIOTest);
   REGISTER_TEST(itkStimulateImageIOTest2);
   REGISTER_TEST(itkGEImageIOTest);
