@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkMetaImageIOTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2008-01-24 14:01:22 $
-  Version:   $Revision: 1.11 $
+  Date:      $Date: 2010-06-22 13:02:54 $
+  Version:   $Revision: 1.13 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -22,6 +22,7 @@
 #include "itkImageFileReader.h"
 #include "itkImageFileWriter.h"
 #include "itkImage.h"
+#include "itkMetaImageIO.h"
 
 int itkMetaImageIOTest(int ac, char* av[])
 {
@@ -39,6 +40,31 @@ int itkMetaImageIOTest(int ac, char* av[])
   itk::ImageFileReader<myImage>::Pointer reader 
                                   = itk::ImageFileReader<myImage>::New();
   
+  // force use of MetaIO
+  typedef itk::MetaImageIO IOType;
+  IOType::Pointer metaIn = IOType::New();
+  metaIn->SetDoublePrecision(8);  // Set manually for coverage
+  reader->SetImageIO(metaIn);
+  
+  // check usability of dimension (for coverage)
+  if (!metaIn->SupportsDimension(3))
+    {
+    std::cerr << "Did not support dimension 3" << std::endl;
+    return EXIT_FAILURE;
+    }
+  
+  // test subsampling factor (change it then change it back)
+  unsigned int origSubSamplingFactor = metaIn->GetSubSamplingFactor();
+  unsigned int subSamplingFactor = 2;
+  metaIn->SetSubSamplingFactor(subSamplingFactor);
+  if (metaIn->GetSubSamplingFactor() != subSamplingFactor)
+    {
+    std::cerr << "Did not set/get Sub Sampling factor correctly" << std::endl;
+    return EXIT_FAILURE;
+    }
+  metaIn->SetSubSamplingFactor(origSubSamplingFactor);
+  
+  // read the file
   reader->SetFileName(av[1]);
   try
     {
@@ -64,6 +90,8 @@ int itkMetaImageIOTest(int ac, char* av[])
   // Generate test image
   itk::ImageFileWriter<myImage>::Pointer writer;
   writer = itk::ImageFileWriter<myImage>::New();
+  IOType::Pointer metaOut = IOType::New();
+  writer->SetImageIO(metaOut);
   writer->SetInput( reader->GetOutput() );
   writer->SetFileName( av[2] );
   writer->Update();
