@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: testMetaGroup.cxx,v $
   Language:  C++
-  Date:      $Date: 2005-02-24 17:03:22 $
-  Version:   $Revision: 1.4 $
+  Date:      $Date: 2009-11-13 17:51:20 $
+  Version:   $Revision: 1.6 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -21,11 +21,18 @@
 #include <stdio.h>
 #include <fstream>
 #include <ctype.h>
+#include <cstdlib>
 
 #include <metaGroup.h>
+#include <itksys/SystemTools.hxx>
 
-int testMetaGroup(int , char *[])
-  {
+int testMetaGroup(int argc, char *argv[])
+{
+  if (argc > 1)
+    {
+    itksys::SystemTools::ChangeDirectory(argv[1]);
+    }
+    
   // Testing metaGroup
   std::cout << "--- Testing metaGroup ---" << std::endl;
 
@@ -48,7 +55,4 @@ int testMetaGroup(int , char *[])
 
   std::cout << "[DONE]" << std::endl;
   return EXIT_SUCCESS;
-  }
-
-
-
+}
