@@ -3,8 +3,8 @@
 Program:   Insight Segmentation & Registration Toolkit
 Module:    $RCSfile: QPropXORTest1.cxx,v $
 Language:  C++
-Date:      $Date: 2007-08-17 13:10:57 $
-Version:   $Revision: 1.5 $
+Date:      $Date: 2009-04-05 23:09:36 $
+Version:   $Revision: 1.6 $
 
 Copyright (c) Insight Software Consortium. All rights reserved.
 See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -145,8 +145,8 @@ QPropXORTest1(int argc, char* argv[])
       std::cout << "Network Output = " << ov << std::endl;
       std::cout << "Target = " << tv << std::endl;
       flag = 0;
-      std::cout<<fabs(tv[0]-ov[0])<<std::endl;
-      if (fabs(tv[0]-ov[0])>0.2)
+      std::cout<<vcl_fabs(tv[0]-ov[0])<<std::endl;
+      if (vcl_fabs(tv[0]-ov[0])>0.2)
         {
         flag = 1;
         }
