@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkContourExtractor2DImageFilterTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2007-01-22 16:18:03 $
-  Version:   $Revision: 1.10 $
+  Date:      $Date: 2009-03-14 16:10:14 $
+  Version:   $Revision: 1.11 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -424,9 +424,9 @@ itkContourExtractor2DImageFilterTestNamespace::MyVertexListList& correct)
 
       const itkContourExtractor2DImageFilterTestNamespace::VertexType& 
           vertex = vertices->ElementAt(j);
-      if (fabs(correctVertex.first - vertex[0]) > 
+      if (vnl_math_abs(correctVertex.first - vertex[0]) > 
             itkContourExtractor2DImageFilterTestNamespace::FLOAT_EPSILON ||
-          fabs(correctVertex.second - vertex[1]) > 
+          vnl_math_abs(correctVertex.second - vertex[1]) > 
             itkContourExtractor2DImageFilterTestNamespace::FLOAT_EPSILON)
         {
         return false;
