@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkReviewTests5.cxx,v $
   Language:  C++
-  Date:      $Date: 2009-12-14 04:04:20 $
-  Version:   $Revision: 1.1 $
+  Date:      $Date: 2010-06-18 13:32:52 $
+  Version:   $Revision: 1.3 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -25,5 +25,7 @@ void RegisterTests()
 {
   vnl_sample_reseed(8775070);
   REGISTER_TEST(itkLabelGeometryImageFilterTest);
+  REGISTER_TEST(itkMRCImageIOTest);
+  REGISTER_TEST(itkVTKImageIO2Test);
 
 }
