@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkTransformFileReaderWriterTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2010-02-08 20:25:17 $
-  Version:   $Revision: 1.5 $
+  Date:      $Date: 2010-06-24 15:00:38 $
+  Version:   $Revision: 1.8 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -22,10 +22,14 @@
 #include "itkTransformFileWriter.h"
 #include "itkTransformIOFactory.h"
 #include "itkAffineTransform.h"
-
+#include "itkTransformFactory.h"
+#include "itkScaleVersor3DTransform.h"
+#include "itkBSplineDeformableTransform.h"
 
 int itkTransformFileReaderWriterTest( int argc, char *argv[] )
 {
+  itk::TransformFactory<itk::ScaleVersor3DTransform<float> >::RegisterDefaultTransforms();
+  itk::TransformFactory<itk::ScaleVersor3DTransform<float> >::RegisterTransform ();
   if( argc < 3 )
     {
     std::cerr << "Missing Parameters " << std::endl;
@@ -83,6 +87,10 @@ int itkTransformFileReaderWriterTest( int argc, char *argv[] )
               << excp << std::endl;
     }
   
+  //DEBUG
+  std::cout << "Reading " << argv[1] << std::endl;
+  
+  
   transformReader->SetFileName( argv[1] );
   std::cout << "Filename: " << transformReader->GetFileName() << std::endl;
   transformReader->Update();
