@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkImageSpatialObjectTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2006-09-05 14:19:45 $
-  Version:   $Revision: 1.15 $
+  Date:      $Date: 2009-04-07 14:34:48 $
+  Version:   $Revision: 1.17 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -74,6 +74,7 @@ int itkImageSpatialObjectTest(int, char* [])
   it.GoToBegin();
 
   ImageSpatialObject::Pointer imageSO = ImageSpatialObject::New();
+  imageSO->Print(std::cout);
  
   imageSO->SetImage(image);
   ImageSpatialObject::TransformType::OffsetType offset;
@@ -162,7 +163,7 @@ int itkImageSpatialObjectTest(int, char* [])
     }
 
   std::cout<<"ValueAt() with interpolator...";
-  if( fabs(returnedValue-expectedValue)>0.001 )
+  if( vcl_fabs(returnedValue-expectedValue)>0.001 )
     {
     std::cout << "Expected: " << expectedValue << " returned: " << returnedValue << std::endl;
     return EXIT_FAILURE;
@@ -178,9 +179,9 @@ int itkImageSpatialObjectTest(int, char* [])
   expectedDerivative[1]=10;
   expectedDerivative[2]=100;
   std::cout<<"DerivativeAt() with interpolator ...";
-  if( fabs(derivative[0]-expectedDerivative[0])>0.00001
-    || fabs(derivative[1]-expectedDerivative[1])>0.00001
-    || fabs(derivative[2]-expectedDerivative[2])>0.00001
+  if(  vcl_fabs(derivative[0]-expectedDerivative[0])>0.00001
+    || vcl_fabs(derivative[1]-expectedDerivative[1])>0.00001
+    || vcl_fabs(derivative[2]-expectedDerivative[2])>0.00001
     )
     {
     std::cout << "Expected: " << derivative << " returned: " << expectedDerivative << std::endl;
@@ -192,6 +193,7 @@ int itkImageSpatialObjectTest(int, char* [])
     std::cout<<"[PASSED]"<<std::endl;
     }
 
+  imageSO->Print(std::cout);
 
   return EXIT_SUCCESS;
 }
