@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkSpatialObjectTests5.cxx,v $
   Language:  C++
-  Date:      $Date: 2005-09-18 00:17:35 $
-  Version:   $Revision: 1.1 $
+  Date:      $Date: 2010-06-10 12:38:35 $
+  Version:   $Revision: 1.3 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -24,7 +24,9 @@
 
 void RegisterTests()
 {
+  REGISTER_TEST(itkContourSpatialObjectTest);
   REGISTER_TEST(itkCylinderSpatialObjectTest);
   REGISTER_TEST(itkEllipseSpatialObjectTest);
   REGISTER_TEST(itkGaussianSpatialObjectTest);
+  REGISTER_TEST(itkMetaArrowConverterTest);
 }
