@@ -3,8 +3,8 @@
   Program:   DICOMParser
   Module:    $RCSfile: DICOMAppHelper.h,v $
   Language:  C++
-  Date:      $Date: 2007-08-20 14:01:50 $
-  Version:   $Revision: 1.30 $
+  Date:      $Date: 2009-04-05 10:56:56 $
+  Version:   $Revision: 1.32 $
 
   Copyright (c) 2003 Matt Turek
   All rights reserved.
@@ -25,7 +25,8 @@
 #endif 
 
 #include <vector>
-#include <string>
+#include <string.h>
+#include <cstring>
 
 #include "DICOMConfig.h"
 #include "DICOMTypes.h"
