@@ -3,8 +3,8 @@
   Program:   gdcm
   Module:    $RCSfile: gdcmPixelReadConvert.cxx,v $
   Language:  C++
-  Date:      $Date: 2008-05-28 11:26:41 $
-  Version:   $Revision: 1.11 $
+  Date:      $Date: 2009-03-24 21:56:26 $
+  Version:   $Revision: 1.14 $
                                                                                 
   Copyright (c) CREATIS (Centre de Recherche et d'Applications en Traitement de
   l'Image). All rights reserved. See Doc/License.txt or
@@ -44,7 +44,7 @@ bool gdcm_read_JPEG2000_file (void* raw,
 //-----------------------------------------------------------------------------
 // Constructor / Destructor
 /// Constructor
-PixelReadConvert::PixelReadConvert()
+PixelReadConvert::PixelReadConvert() 
 {
    RGB          = 0;
    RGBSize      = 0;
@@ -163,7 +163,8 @@ void PixelReadConvert::GrabInformationsFromFile( File *file )
 
    /////////////////////////////////////////////////////////////////
    // LUT section:
-   HasLUT = file->HasLUT();
+   HasLUT = false;
+   if( IsPaletteColor ) HasLUT = file->HasLUT();
    if ( HasLUT )
    {
       // Just in case some access to a File element requires disk access.
@@ -490,7 +491,7 @@ bool PixelReadConvert::ReadAndDecompressJPEGFile( std::ifstream *fp )
        {
        if( (unsigned int)ZSize != JPEGInfo->GetFragmentCount() )
          {
-         gdcmErrorMacro( "Sorry GDCM does not handle this type of fragments" );
+         gdcmErrorMacro( "Sorry GDCM does not handle this type of fragments: " << ZSize << " vs " << JPEGInfo->GetFragmentCount() );
          return false;
          }
        // Hopefully every dicom fragment is *exactly* the j2k stream
@@ -565,7 +566,14 @@ bool PixelReadConvert::ReadAndDecompressJPEGFile( std::ifstream *fp )
      int length = XSize * YSize * SamplesPerPixel;
      int numberBytes = BitsAllocated / 8;
 
-     JPEGInfo->DecompressFromFile(fp, Raw, BitsStored, numberBytes, length );
+     if( !JPEGInfo->DecompressFromFile(fp, Raw, BitsStored, numberBytes, length ) )
+       {
+       gdcmWarningMacro( "JPEG encapsulated does not match" );
+       if(!JPEGInfo->DecompressFromFile(fp, Raw, BitsAllocated, numberBytes, length ))
+         {
+         return false;
+         }
+       }
      return true;
    }
    //else (not sure how get there...), must be one of those crazy DICOM file
@@ -1057,7 +1065,7 @@ bool PixelReadConvert::ConvertReArrangeBits() throw ( FormatError )
             // nmask : to propagate sign bit on negative values
             int16_t nmask = (int16_t)0x8000;  
             nmask = nmask >> ( BitsAllocated - BitsStored - 1 );
-
+ 
             for(int i = 0; i<l; i++)
             {
                *deb = *deb >> (BitsStored - HighBitPosition - 1);
@@ -1159,9 +1167,9 @@ void PixelReadConvert::ConvertYcBcRPlanesToRGBPixels()
   // except for the few patches of color on the image.
   // On such images, RLE achieves a compression ratio that is much better 
   // than the compression ratio on an equivalent RGB image. 
-
+ 
    gdcmWarningMacro("--> ConvertYcBcRPlanesToRGBPixels");
-
+   
    uint8_t *localRaw = Raw;
    uint8_t *copyRaw = new uint8_t[ RawSize ];
    memmove( copyRaw, localRaw, RawSize );
