@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: wrap_itkVersorTransform.cxx,v $
   Language:  C++
-  Date:      $Date: 2005/03/25 13:17:57 $
-  Version:   $Revision: 1.1 $
+  Date:      $Date: 2007-11-02 15:59:47 $
+  Version:   $Revision: 1.2 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -15,6 +15,7 @@
 
 =========================================================================*/
 #include "itkVersorTransform.h"
+#include "itkVersorRigid3DTransform.h"
 
 #ifdef CABLE_CONFIGURATION
 #include "itkCSwigMacros.h"
@@ -28,6 +29,7 @@ namespace _cable_
   namespace wrappers
   {
     ITK_WRAP_TRANSFORM_1(VersorTransform);
+    ITK_WRAP_TRANSFORM_1(VersorRigid3DTransform);
   }
 }
 #endif
